var blocklyArea = document.getElementById('blocklyArea');
var blocklyDiv = document.getElementById('blocklyDiv');
var outputArea = document.getElementById('consoleArea');
var stepButton = document.getElementById('btnStep');
var myInterpreter = null;
var highlightPause = false;
var latestCode = '';
var pid;

var options = { 
    toolbox : document.getElementById('toolbox'), 
    media: 'media/',
    grid:
     {spacing: 20,
      length: 3,
      colour: '#ccc',
      snap: true},
    trashcan: true,
    zoom:
     {controls: true,
      wheel: true,
      startScale: 1.0,
      maxScale: 3,
      minScale: 0.3,
      scaleSpeed: 1.2},        
    collapse : true, 
    comments : true, 
    disable : true, 
    maxBlocks : Infinity, 
    horizontalLayout : false, 
    toolboxPosition : 'start', 
    css : true, 
    rtl : false, 
    scrollbars : true, 
    sounds : true, 
    oneBasedIndex : true
};


var algorithmEnd = {
  "type": "algorithm_end",
  "message0": "Τέλος %1",
  "args0": [
    {
      "type": "field_input",
      "name": "algorithm_name",
      "text": "Όνομα"
    }
  ],
  "previousStatement": null,
  "colour": 65,
  "tooltip": "Δώσε ένα όνομα στον αλγόριθμο",
  "helpUrl": ""
};    
Blockly.Blocks['algorithm_end'] = {
  init: function() {
    this.jsonInit(algorithmEnd);
    // Assign 'this' to a variable for use in the tooltip closure below.
    var thisBlock = this;
    this.setTooltip(function() {
      return 'Τέλος αλγορίθμου';
    });
  }
};
Blockly.JavaScript['algorithm_end'] = function(block) {
  var text_algorithm_name = block.getFieldValue('algorithm_name');
  var code = '';
  return code;
};
Blockly.Python['algorithm_end'] = function(block) {  
  var code = '';
  return code;
};

var algorithmStart = {
  "type": "algorithm_start",
  "message0": "Αλγόριθμος %1",
  "args0": [
    {
      "type": "field_input",
      "name": "algorithm_name",
      "text": "Όνομα"
    }
  ],
  "nextStatement": null,
  "colour": 65,
  "tooltip": "",
  "helpUrl": ""
};   
Blockly.Blocks['algorithm_start'] = {
  init: function() {
    this.jsonInit(algorithmStart);
    // Assign 'this' to a variable for use in the tooltip closure below.
    var thisBlock = this;
    this.setTooltip(function() {
      return 'Αρχή αλγορίθμου';
    });
  }
};
Blockly.JavaScript['algorithm_start'] = function(block) {
  var text_algorithm_name = block.getFieldValue('algorithm_name');  
  var code = '';
  return code;
};
Blockly.Python['algorithm_start'] = function(block) {  
  var code = '';
  return code;
};

var Workspace = Blockly.inject(blocklyDiv, options);

var onresize = function(e) {
  // Compute the absolute coordinates and dimensions of blocklyArea.
  var element = blocklyArea;
  var x = 0;
  var y = 0;
  do {
    x += element.offsetLeft;
    y += element.offsetTop;
    element = element.offsetParent;
  } while (element);
  // Position blocklyDiv over blocklyArea.
  blocklyDiv.style.left = x + 'px';
  blocklyDiv.style.top = y + 'px';
  blocklyDiv.style.width = blocklyArea.offsetWidth + 'px';
  blocklyDiv.style.height = blocklyArea.offsetHeight + 'px';
  Blockly.svgResize(Workspace);
};

window.addEventListener('resize', onresize, false);
onresize();
Blockly.svgResize(Workspace);

        
        
function initApi(interpreter, scope) {          
  interpreter.setProperty(scope, 'alert',interpreter.createNativeFunction(function(text) {
    text = text ? text.toString() : '';
    //outputArea.value += '\n' + text;
      outputArea.innerHTML += '<br>' + text;
  }));

  var wrapper = function(text) {
      text = text ? text.toString() : '';
        return interpreter.createPrimitive(prompt(text));
  };

  interpreter.setProperty(scope, 'prompt',interpreter.createNativeFunction(wrapper));

  var wrapper = function(id) {
    id = id ? id.toString() : '';
    return interpreter.createPrimitive(highlightBlock(id));
  };

  interpreter.setProperty(scope, 'highlightBlock',interpreter.createNativeFunction(wrapper));
}



function highlightBlock(id) {
  Workspace.highlightBlock(id);
  highlightPause = true;
}

function resetStepUi(clearOutput) {
  Workspace.highlightBlock(null);
  highlightPause = false;

  if (clearOutput) {
        //outputArea.value = '\n';
        outputArea.innerHTML = '';
  }
}

function generateCodeAndLoadIntoInterpreter() {  
  Blockly.JavaScript.STATEMENT_PREFIX = 'highlightBlock(%1);\n';
  Blockly.JavaScript.addReservedWords('highlightBlock');
  latestCode = Blockly.JavaScript.workspaceToCode(Workspace);
  resetStepUi(true);
}

function stepCode() {
  if (!myInterpreter) {
    resetStepUi(true);
    myInterpreter = new Interpreter(latestCode, initApi);

    pid = setTimeout(function() {
        //alert('Εκτέλεση εντολών\n' + latestCode);
        highlightPause = true;
        stepCode();
    }, 1);
    return;
  }
    
  highlightPause = false;
  do {
    try {
      var hasMoreCode = myInterpreter.step();
    } finally {
      if (!hasMoreCode) {        
            //outputArea.value += '\n';
            outputArea.innerHTML += '';

        myInterpreter = null;
        resetStepUi(false);
        
        stepButton.disabled = 'disabled';
        setTimeout(function() {
          stepButton.disabled = '';
        }, 2000);

        return;
      }
    }

  } while (hasMoreCode && !highlightPause);
}


generateCodeAndLoadIntoInterpreter();
Workspace.addChangeListener(function(event) {
  if (!(event instanceof Blockly.Events.Ui)) {    
    generateCodeAndLoadIntoInterpreter();
  }
});

    function NewProgram() {
        Blockly.mainWorkspace.clear();
        let xmlBlock = Blockly.Xml.textToDom('<xml><block type="algorithm_start" x="100" y="50"><field name="TEXT">123</field></block></xml>');
        Blockly.Xml.domToWorkspace(xmlBlock, Workspace);
        xmlBlock = Blockly.Xml.textToDom('<xml><block type="algorithm_end" x="100" y="250"><field name="TEXT">123</field></block></xml>');
        Blockly.Xml.domToWorkspace(xmlBlock, Workspace);    
    }


    function LoadAlgorithm(xmlAlgorithm) {
        Workspace.clear();
        let xml = Blockly.Xml.textToDom(xmlAlgorithm);
        Blockly.Xml.domToWorkspace(xml, Workspace);
    }


    $('#algorithmSelection').change(function () {
                
        optionSelected = $(this).find('option:selected').val();
        var answer = confirm("Προσοχή! Το τρέχον πρόγραμμα σας θα χαθεί");
                 
        if (answer == true) {            
            switch(optionSelected) {
                case "0" :
                    NewProgram();                    
                break;
                case "1":
                    LoadAlgorithm('<xml xmlns="http://www.w3.org/1999/xhtml"><variables><variable type="" id="f;`?tA*Uhk`SK$Og;?~[">A</variable><variable type="" id="=6}Tv-Qou7PGaZCS$2C6">B</variable><variable type="" id="5LBw^@^}/{nd=y#,*|[u">Temp</variable></variables><block type="algorithm_start" id="^1n{eg$0%l1EXPAT)-)D" x="50" y="50"><field name="algorithm_name">Αντιμετάθεση</field><next><block type="variables_set" id="R{|Y(:iHUj500H18Dz51"><field name="VAR" id="f;`?tA*Uhk`SK$Og;?~[" variabletype="">A</field><value name="VALUE"><block type="text_prompt_ext" id="91v{K|.;yJh+ycII`EX9"><mutation type="NUMBER"></mutation><field name="TYPE">NUMBER</field><value name="TEXT"><shadow type="text" id="]XQcF+LBfp~~AZ9aWYUH"><field name="TEXT">Τιμή μεταβλητής Α : </field></shadow></value></block></value><next><block type="variables_set" id="=Y3y|Za/q~IAZP*Ue=v1"><field name="VAR" id="=6}Tv-Qou7PGaZCS$2C6" variabletype="">B</field><value name="VALUE"><block type="text_prompt_ext" id="y!~**Ed3Ab2iuGTlV=tp"><mutation type="NUMBER"></mutation><field name="TYPE">NUMBER</field><value name="TEXT"><shadow type="text" id="pXb|2FR=3vRz:f:5K%iI"><field name="TEXT">Τιμή μεταβλητής Β: </field></shadow></value></block></value><next><block type="variables_set" id="[_9e3Zi%+=$S7BL(@_wE"><field name="VAR" id="5LBw^@^}/{nd=y#,*|[u" variabletype="">Temp</field><value name="VALUE"><block type="variables_get" id="dmp@(82-CZMn)9vksia`"><field name="VAR" id="f;`?tA*Uhk`SK$Og;?~[" variabletype="">A</field></block></value><next><block type="variables_set" id="@z8$#q{Ms$6;#c|-7I5m"><field name="VAR" id="f;`?tA*Uhk`SK$Og;?~[" variabletype="">A</field><value name="VALUE"><block type="variables_get" id="2d8m6sY#)oF60W[}-XAB"><field name="VAR" id="=6}Tv-Qou7PGaZCS$2C6" variabletype="">B</field></block></value><next><block type="variables_set" id="g!113CD^Czhi7tlpt`pS"><field name="VAR" id="=6}Tv-Qou7PGaZCS$2C6" variabletype="">B</field><value name="VALUE"><block type="variables_get" id="49WjWHFDsa_L:QK`C!@("><field name="VAR" id="5LBw^@^}/{nd=y#,*|[u" variabletype="">Temp</field></block></value><next><block type="text_print" id="yc$Bpz7)}vV.OTa/,a.Q"><value name="TEXT"><shadow type="text" id="!RPqZksaPM^b?oiX2]}g"><field name="TEXT">abc</field></shadow><block type="text_join" id="uuKZE?R47xbjwbJTcR/;"><mutation items="2"></mutation><value name="ADD0"><block type="text" id="XR{FfTlSl{7u?)9Oa=HB"><field name="TEXT">Νέα τιμή μεταβλητής Α : </field></block></value><value name="ADD1"><block type="variables_get" id="w/:}ZR)!,KdJzVrQcfv|"><field name="VAR" id="f;`?tA*Uhk`SK$Og;?~[" variabletype="">A</field></block></value></block></value><next><block type="text_print" id="hNOqU53(%}Qo9mNUv_E/"><value name="TEXT"><shadow type="text" id="!RPqZksaPM^b?oiX2]}g"><field name="TEXT">abc</field></shadow><block type="text_join" id="Go}Ue97.^ihm;?Q)Hy3E"><mutation items="2"></mutation><value name="ADD0"><block type="text" id="|imSFd.-l1~y}x=udU4?"><field name="TEXT">Νέα τιμή μεταβλητής Β : </field></block></value><value name="ADD1"><block type="variables_get" id="GioCr.%|Qe69_@Wb,_^;"><field name="VAR" id="=6}Tv-Qou7PGaZCS$2C6" variabletype="">B</field></block></value></block></value><next><block type="algorithm_end" id="fnFLr@C1TdF{n9^+M3$d"><field name="algorithm_name">Αντιμετάθεση</field></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></xml>');                    
                break;
                case "2":
                    LoadAlgorithm('<xml xmlns="http://www.w3.org/1999/xhtml"><variables><variable type="" id="7|RDRh)XO9I!]|3I8?rV">A</variable></variables><block type="algorithm_start" id="pXspnnMrw,!xg?Ec-D9m" x="30" y="50"><field name="algorithm_name">Απόλυτη τιμή</field><next><block type="variables_set" id="R^JG5CLtT|qCW_`w]Q,-"><field name="VAR" id="7|RDRh)XO9I!]|3I8?rV" variabletype="">A</field><value name="VALUE"><block type="text_prompt_ext" id="EkB]ze,gmYN`5?G;2XPs"><mutation type="NUMBER"></mutation><field name="TYPE">NUMBER</field><value name="TEXT"><shadow type="text" id="}?D=yOCRu[CeFe}2^9i,"><field name="TEXT">Τιμή για μεταβλητή Α</field></shadow></value></block></value><next><block type="controls_if" id="@fC5d0LrH23|bq*k:xvA"><value name="IF0"><block type="logic_compare" id="3fP!9N/Z(,1Nyh95z*FP"><field name="OP">LT</field><value name="A"><block type="variables_get" id="uh~K~D#n63YuT3?0lZ,`"><field name="VAR" id="7|RDRh)XO9I!]|3I8?rV" variabletype="">A</field></block></value><value name="B"><block type="math_number" id="KUU.U*eZ9BHYXi_F=#k]"><field name="NUM">0</field></block></value></block></value><statement name="DO0"><block type="variables_set" id="iV#T[-nthr-a_cPUM^HK"><field name="VAR" id="7|RDRh)XO9I!]|3I8?rV" variabletype="">A</field><value name="VALUE"><block type="math_arithmetic" id="Y:+|nIA?c,$(xAsAst#;"><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id="`h1TbKLI7xPhV7.i*K7K"><field name="NUM">1</field></shadow><block type="variables_get" id="76r.z`1m}p`[!iBplx$("><field name="VAR" id="7|RDRh)XO9I!]|3I8?rV" variabletype="">A</field></block></value><value name="B"><shadow type="math_number" id="S)@IzY{}T$js*.l`C4:P"><field name="NUM">-1</field></shadow></value></block></value></block></statement><next><block type="text_print" id="t;vN$Fe[`Kt~q|TRIxd="><value name="TEXT"><shadow type="text" id="]muj0k@TpySWzQ4Di$Sx"><field name="TEXT">abc</field></shadow><block type="text_join" id="Bbnz|~VD8.J0@E)2|g.Z"><mutation items="2"></mutation><value name="ADD0"><block type="text" id="Yd3GKvvILcrUk@|]h#c:"><field name="TEXT">Η απόλυτη τιμή της Α είναι : </field></block></value><value name="ADD1"><block type="variables_get" id="Ncd!_gXxcrG_YIjDSanV"><field name="VAR" id="7|RDRh)XO9I!]|3I8?rV" variabletype="">A</field></block></value></block></value><next><block type="algorithm_end" id=",{OB+q:rN35fE;S,}Xb4"><field name="algorithm_name">Απόλυτη τιμή</field></block></next></block></next></block></next></block></next></block></xml>');                    
                break;
                case "3":
                    LoadAlgorithm('<xml xmlns="http://www.w3.org/1999/xhtml"><variables><variable type="" id="9bD^|mf[Xh,xX~j-?{HC">X</variable><variable type="" id="yWT!MUqsn=867,t=TAGl">Y</variable><variable type="" id="87w=iU6GOrweXP#EAkqR">Z</variable></variables><block type="algorithm_start" id="DC}:]W[q+`=_)Z452VU$" x="70" y="30"><field name="algorithm_name">Μέγιστος Κοινός Διαιρέτης (Ευκλείδης)</field><next><block type="variables_set" id="c,W.Xg]{cO=n}?f{,Hlo"><field name="VAR" id="9bD^|mf[Xh,xX~j-?{HC" variabletype="">X</field><value name="VALUE"><block type="text_prompt_ext" id="hEnEMPXh(03LoF4+IDjn"><mutation type="NUMBER"></mutation><field name="TYPE">NUMBER</field><value name="TEXT"><shadow type="text" id="85s4/cQbpr6nH-]e1-Y%"><field name="TEXT">Τιμή για μεταβλητή Χ</field></shadow></value></block></value><next><block type="variables_set" id="kt7),#Dp8Tqqvt*g7W(,"><field name="VAR" id="yWT!MUqsn=867,t=TAGl" variabletype="">Y</field><value name="VALUE"><block type="text_prompt_ext" id="eXiV+kRAED]1vpD9;YA^"><mutation type="NUMBER"></mutation><field name="TYPE">NUMBER</field><value name="TEXT"><shadow type="text" id="4Wn;HJwq|c/#N#}A/GuY"><field name="TEXT">Τιμή για μεταβλητή Υ</field></shadow></value></block></value><next><block type="variables_set" id="JPlg2#fvWb2`5(oY}V22"><field name="VAR" id="87w=iU6GOrweXP#EAkqR" variabletype="">Z</field><value name="VALUE"><block type="variables_get" id="MFjhc:y6e:yi%PK2x_:|"><field name="VAR" id="yWT!MUqsn=867,t=TAGl" variabletype="">Y</field></block></value><next><block type="controls_whileUntil" id="nuYme(kG^[ccGVeUkUxO"><field name="MODE">WHILE</field><value name="BOOL"><block type="logic_compare" id="*SQuV(;~[wnon9{;*==J"><field name="OP">NEQ</field><value name="A"><block type="variables_get" id="rrp|ZXSRc@Ri!71YF)S["><field name="VAR" id="87w=iU6GOrweXP#EAkqR" variabletype="">Z</field></block></value><value name="B"><block type="math_number" id="7(d-Cw$.O0_%9u}k^EVq"><field name="NUM">0</field></block></value></block></value><statement name="DO"><block type="variables_set" id="T5kMSNd!_t5dgQLg0z^p"><field name="VAR" id="87w=iU6GOrweXP#EAkqR" variabletype="">Z</field><value name="VALUE"><block type="math_modulo" id="+cLoPWh$5I18M,cCT*9d"><value name="DIVIDEND"><shadow type="math_number" id="6_1WT[xi!P#-gJw:-I?2"><field name="NUM">64</field></shadow><block type="variables_get" id="=ffSY*i^/:bUXmQPKqc#"><field name="VAR" id="9bD^|mf[Xh,xX~j-?{HC" variabletype="">X</field></block></value><value name="DIVISOR"><shadow type="math_number" id="~wpNFT^F*T4s1.o?$.uK"><field name="NUM">10</field></shadow><block type="variables_get" id=";U?4%CPLUsoaLFJPU,*F"><field name="VAR" id="87w=iU6GOrweXP#EAkqR" variabletype="">Z</field></block></value></block></value><next><block type="variables_set" id="8G|doY|dgN,!3rGd_m[9"><field name="VAR" id="9bD^|mf[Xh,xX~j-?{HC" variabletype="">X</field><value name="VALUE"><block type="variables_get" id="!`z;a!q!#NfZKwPBmUc4"><field name="VAR" id="yWT!MUqsn=867,t=TAGl" variabletype="">Y</field></block></value><next><block type="variables_set" id="Yro0NE:Sz)nv_{}snYlN"><field name="VAR" id="yWT!MUqsn=867,t=TAGl" variabletype="">Y</field><value name="VALUE"><block type="variables_get" id="k8mJ6(o#rQGRGq@uN%NO"><field name="VAR" id="87w=iU6GOrweXP#EAkqR" variabletype="">Z</field></block></value></block></next></block></next></block></statement><next><block type="text_print" id="-?FMahs?qmrQCuZ`4`,O"><value name="TEXT"><shadow type="text" id="oOg9z$@+mF2-=k[:-in:"><field name="TEXT">abc</field></shadow><block type="text_join" id="JA=f:#)oNP;m?1yZs5)?"><mutation items="2"></mutation><value name="ADD0"><block type="text" id="OrP066?5+]dOZRt,z.k~"><field name="TEXT">Ο ΜΚΔ είναι ο : </field></block></value><value name="ADD1"><block type="variables_get" id="IWo)Lcnn~|J+0Vk6F`7E"><field name="VAR" id="9bD^|mf[Xh,xX~j-?{HC" variabletype="">X</field></block></value></block></value><next><block type="algorithm_end" id="WkSx?;n?${.c9U)(-MN3"><field name="algorithm_name">Μέγιστος Κοινός Διαιρέτης (Ευκλείδης)</field></block></next></block></next></block></next></block></next></block></next></block></next></block></xml>');                    
                break;
                case "4":
                    LoadAlgorithm('<xml xmlns="http://www.w3.org/1999/xhtml"><variables><variable type="" id="]CQi8BNBYffN`aFZ^7@A">A</variable><variable type="" id="Tc$b7~Y]QJ$Z=8Tiz0QS">B</variable><variable type="" id="A$9xyrp%NJ-poWl^0B)O">C</variable><variable type="" id="lQg{!(vj}tp0SeRCL1(L">T</variable><variable type="" id="OW[^L%4nm3.%_calueBZ">EMB</variable></variables><block type="algorithm_start" id="@Nu~ySC1Qle0z_~X:KJq" x="70" y="50"><field name="algorithm_name">Εμβαδόν Τριγώνου</field><next><block type="variables_set" id="|1*8SX]E(%1$m2*1l}H!"><field name="VAR" id="]CQi8BNBYffN`aFZ^7@A" variabletype="">A</field><value name="VALUE"><block type="text_prompt_ext" id="GbdV0HQD_:4hPH]_v(yr"><mutation type="NUMBER"></mutation><field name="TYPE">NUMBER</field><value name="TEXT"><shadow type="text" id="+#NG;Bdlx[1G7SI]?^84"><field name="TEXT">Τιμή μεταβλητής Α :</field></shadow></value></block></value><next><block type="variables_set" id="k|]?|dH_pQ/Vidx{U{~,"><field name="VAR" id="Tc$b7~Y]QJ$Z=8Tiz0QS" variabletype="">B</field><value name="VALUE"><block type="text_prompt_ext" id="@G*#h4hvT|IR%zEPm=*p"><mutation type="NUMBER"></mutation><field name="TYPE">NUMBER</field><value name="TEXT"><shadow type="text" id="Xto-K-9*D0)iax0tmtEM"><field name="TEXT">Τιμή μεταβλητής B :</field></shadow></value></block></value><next><block type="variables_set" id="HTa%:DD`%Q@zZwpIy@ke"><field name="VAR" id="A$9xyrp%NJ-poWl^0B)O" variabletype="">C</field><value name="VALUE"><block type="text_prompt_ext" id="N^N:_rX@hM-OlacxniX*"><mutation type="NUMBER"></mutation><field name="TYPE">NUMBER</field><value name="TEXT"><shadow type="text" id="T2INY$uT:Yj75}2(u81-"><field name="TEXT">Τιμή μεταβλητής C :</field></shadow></value></block></value><next><block type="controls_if" id="),P-kruaOemcY)|QedXe"><mutation else="1"></mutation><value name="IF0"><block type="logic_operation" id="j*c4rd,;`V.P%Qf]sqps"><field name="OP">AND</field><value name="A"><block type="logic_operation" id="NMa}]W90F@[1YV8DN(1z"><field name="OP">AND</field><value name="A"><block type="logic_compare" id="eBQbWB--!,;LJT]awP0V"><field name="OP">GT</field><value name="A"><block type="math_arithmetic" id=";GDp0MB(a0D$gOjz!XbQ"><field name="OP">ADD</field><value name="A"><shadow type="math_number" id="Gu$QYDVw!Ah~3/vOIZGS"><field name="NUM">1</field></shadow><block type="variables_get" id="};6#XtsKE=yWVAh4%HPI"><field name="VAR" id="]CQi8BNBYffN`aFZ^7@A" variabletype="">A</field></block></value><value name="B"><shadow type="math_number" id="{@QbXh`Ry6;K(w$QW7?S"><field name="NUM">1</field></shadow><block type="variables_get" id="~6.7?e{[fg{kLqj$I*aq"><field name="VAR" id="Tc$b7~Y]QJ$Z=8Tiz0QS" variabletype="">B</field></block></value></block></value><value name="B"><block type="variables_get" id="cq:@GO-cLW`:!T|5!n`+"><field name="VAR" id="A$9xyrp%NJ-poWl^0B)O" variabletype="">C</field></block></value></block></value><value name="B"><block type="logic_compare" id="^._e@)[(u:Z.d72SejAd"><field name="OP">GT</field><value name="A"><block type="math_arithmetic" id="h3p6j4Rdh@fjw9{CJTE+"><field name="OP">ADD</field><value name="A"><shadow type="math_number" id="Gu$QYDVw!Ah~3/vOIZGS"><field name="NUM">1</field></shadow><block type="variables_get" id="zt@2hTjqKJ.YD85[RQiY"><field name="VAR" id="Tc$b7~Y]QJ$Z=8Tiz0QS" variabletype="">B</field></block></value><value name="B"><shadow type="math_number" id="{@QbXh`Ry6;K(w$QW7?S"><field name="NUM">1</field></shadow><block type="variables_get" id="@I!5F[A=h]KLGDkzAW]G"><field name="VAR" id="A$9xyrp%NJ-poWl^0B)O" variabletype="">C</field></block></value></block></value><value name="B"><block type="variables_get" id="@oCMLdvr@zWdwJfrKc:J"><field name="VAR" id="]CQi8BNBYffN`aFZ^7@A" variabletype="">A</field></block></value></block></value></block></value><value name="B"><block type="logic_compare" id="538!nq^Z3qv|x-MZoo/T"><field name="OP">GT</field><value name="A"><block type="math_arithmetic" id="94|yfq_q;:?g@avt7.|d"><field name="OP">ADD</field><value name="A"><shadow type="math_number" id="Gu$QYDVw!Ah~3/vOIZGS"><field name="NUM">1</field></shadow><block type="variables_get" id="By%[f1i,x^F=/-=+Rv@S"><field name="VAR" id="]CQi8BNBYffN`aFZ^7@A" variabletype="">A</field></block></value><value name="B"><shadow type="math_number" id="{@QbXh`Ry6;K(w$QW7?S"><field name="NUM">1</field></shadow><block type="variables_get" id="gP{QJKt#:y2~%w|_D|,X"><field name="VAR" id="A$9xyrp%NJ-poWl^0B)O" variabletype="">C</field></block></value></block></value><value name="B"><block type="variables_get" id="#[d?-VQaqGz$|9[}9~w4"><field name="VAR" id="Tc$b7~Y]QJ$Z=8Tiz0QS" variabletype="">B</field></block></value></block></value></block></value><statement name="DO0"><block type="variables_set" id="1ch-19MgN=gqxIWXM8T6"><field name="VAR" id="lQg{!(vj}tp0SeRCL1(L" variabletype="">T</field><value name="VALUE"><block type="math_arithmetic" id="{^xHQPj4@OV*lk0uHHo0"><field name="OP">DIVIDE</field><value name="A"><shadow type="math_number" id="^w;ykL*|gsyw1-j7R4rh"><field name="NUM">1</field></shadow><block type="math_arithmetic" id="uXVx-R$Q;FBZ=~GcL_jS"><field name="OP">ADD</field><value name="A"><shadow type="math_number" id="@(Z$~8W/5J~rLpDEu;q("><field name="NUM">1</field></shadow><block type="math_arithmetic" id="={cp%#l?Uf)x:j}{IY$B"><field name="OP">ADD</field><value name="A"><shadow type="math_number" id="[0[6B_{jYmIqw6fB!Ety"><field name="NUM">1</field></shadow><block type="variables_get" id="i39gJ68R$#W:40~?~zW#"><field name="VAR" id="]CQi8BNBYffN`aFZ^7@A" variabletype="">A</field></block></value><value name="B"><shadow type="math_number" id="gEydJoPYakB;Flg*Mzh("><field name="NUM">1</field></shadow><block type="variables_get" id="L1wpS9~?!_6rKH+gQ,H*"><field name="VAR" id="Tc$b7~Y]QJ$Z=8Tiz0QS" variabletype="">B</field></block></value></block></value><value name="B"><shadow type="math_number" id="KlJ!yxYP+5%L6`X6HKq;"><field name="NUM">1</field></shadow><block type="variables_get" id="I#]h~x6sCPKA+EV-SEcc"><field name="VAR" id="A$9xyrp%NJ-poWl^0B)O" variabletype="">C</field></block></value></block></value><value name="B"><shadow type="math_number" id="s2dv4feTw6ec,3+}SZh`"><field name="NUM">2</field></shadow></value></block></value><next><block type="variables_set" id="$}_AS=|9/Za5ol/F7-Hl"><field name="VAR" id="OW[^L%4nm3.%_calueBZ" variabletype="">EMB</field><value name="VALUE"><block type="math_single" id="GoY?MF.um|^(obWKrhj1"><field name="OP">ROOT</field><value name="NUM"><shadow type="math_number" id="Ds$wQ|EZ0RoMiO-|30P^"><field name="NUM">9</field></shadow><block type="math_arithmetic" id="k7F(:1p2|?mnR2_`D=`}"><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id=":R]?)B_w)$)SZ*?nW#4X"><field name="NUM">1</field></shadow><block type="variables_get" id="IWP;LLm8YQ.*/wGV1P^w"><field name="VAR" id="lQg{!(vj}tp0SeRCL1(L" variabletype="">T</field></block></value><value name="B"><shadow type="math_number" id="{FLc205!WcP`9HAxaAld"><field name="NUM">1</field></shadow><block type="math_arithmetic" id="R.^8K!Be!=OnTp`ZN[Ln"><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id="]-]T=8Oq/rIxlb?[T#Cy"><field name="NUM">1</field></shadow><block type="math_arithmetic" id="N72r=T+:y-]j9d%a`4Eo"><field name="OP">MINUS</field><value name="A"><shadow type="math_number" id="1tWpX~#F15rU%L|#6#fL"><field name="NUM">1</field></shadow><block type="variables_get" id="0*e$~3rEJK._Kz=1.84H"><field name="VAR" id="lQg{!(vj}tp0SeRCL1(L" variabletype="">T</field></block></value><value name="B"><shadow type="math_number" id="k|{BLJ60fqOa!;G`YRcI"><field name="NUM">1</field></shadow><block type="variables_get" id="Z7bxLl}dzp@QcSn:Z25$"><field name="VAR" id="]CQi8BNBYffN`aFZ^7@A" variabletype="">A</field></block></value></block></value><value name="B"><shadow type="math_number" id="0UPc|xY:J/DE+dNZuu?8"><field name="NUM">1</field></shadow><block type="math_arithmetic" id="DvAt^O*}zu%RWEgu_Es["><field name="OP">MULTIPLY</field><value name="A"><shadow type="math_number" id="ur|F~3_FNPO}{h%rq_-%"><field name="NUM">1</field></shadow><block type="math_arithmetic" id="QvRe}ror[oi|aK9I}4M8"><field name="OP">MINUS</field><value name="A"><shadow type="math_number" id="1tWpX~#F15rU%L|#6#fL"><field name="NUM">1</field></shadow><block type="variables_get" id="4~fD/NQHEqad]twcKIiz"><field name="VAR" id="lQg{!(vj}tp0SeRCL1(L" variabletype="">T</field></block></value><value name="B"><shadow type="math_number" id="k|{BLJ60fqOa!;G`YRcI"><field name="NUM">1</field></shadow><block type="variables_get" id=".^Pr2lb2u8yxs%gZ[;~*"><field name="VAR" id="Tc$b7~Y]QJ$Z=8Tiz0QS" variabletype="">B</field></block></value></block></value><value name="B"><shadow type="math_number" id="tXI[4.TKVOZ+4w%?So!C"><field name="NUM">1</field></shadow><block type="math_arithmetic" id="QDB3Od^9=@bpq?:?imzU"><field name="OP">MINUS</field><value name="A"><shadow type="math_number" id="1tWpX~#F15rU%L|#6#fL"><field name="NUM">1</field></shadow><block type="variables_get" id="+D,;iV}8yF{isXQ%jrk-"><field name="VAR" id="lQg{!(vj}tp0SeRCL1(L" variabletype="">T</field></block></value><value name="B"><shadow type="math_number" id="k|{BLJ60fqOa!;G`YRcI"><field name="NUM">1</field></shadow><block type="variables_get" id="q7su8-Ulffn2jQt1H1cS"><field name="VAR" id="A$9xyrp%NJ-poWl^0B)O" variabletype="">C</field></block></value></block></value></block></value></block></value></block></value></block></value><next><block type="text_print" id="6dqT|(M:hkU:SQX^]`/k"><value name="TEXT"><shadow type="text" id="Y3+tDv@zn8aSIkyNkMzX"><field name="TEXT">abc</field></shadow><block type="text_join" id="{s0J^Dabc4zUT[@zZ(Yh"><mutation items="2"></mutation><value name="ADD0"><block type="text" id="/R|3;}b$`Bf1piU3veD_"><field name="TEXT">Το εμβαδόν του τριγώνου είναι : </field></block></value><value name="ADD1"><block type="variables_get" id="#m_|zg=e|Y6b$F+[[YQA"><field name="VAR" id="OW[^L%4nm3.%_calueBZ" variabletype="">EMB</field></block></value></block></value></block></next></block></next></block></statement><statement name="ELSE"><block type="text_print" id="Ka%aX#SeWmpyz4PAt2vI"><value name="TEXT"><shadow type="text" id="b0:i+Mv9ej=Z$bBb8gr4"><field name="TEXT">Δεν σχηματίζεται τρίγωνο</field></shadow></value></block></statement><next><block type="algorithm_end" id="_1Bk@9lecHmPvzS0re^("><field name="algorithm_name">Εμβαδόν Τριγώνου</field></block></next></block></next></block></next></block></next></block></next></block></xml>');                    
                break;
                case "5" :
                    LoadAlgorithm('<xml xmlns="http://www.w3.org/1999/xhtml"><variables><variable type="" id="Z#/AWt1:c`zJl[5{(3,G">N</variable><variable type="" id="Mu`el/F}wJb~:-Kk0t62">A</variable><variable type="" id="1gl2iW[A[c:88A3b5ES6">i</variable><variable type="" id="1Mn,V*BV[87lM@9b#ea^">j</variable><variable type="" id="~JGwVE_?FUuT?6W8@og+">Temp</variable></variables><block type="algorithm_start" id="g@8{f/DD~e4s9xSgOOSX" x="50" y="30"><field name="algorithm_name">Bubble sort</field><next><block type="variables_set" id="iS~}xu2Wwa7MXNab~=r."><field name="VAR" id="Z#/AWt1:c`zJl[5{(3,G" variabletype="">N</field><value name="VALUE"><block type="text_prompt_ext" id="8UW_m1|^r,eg4ItXj(iu"><mutation type="NUMBER"></mutation><field name="TYPE">NUMBER</field><value name="TEXT"><shadow type="text" id="S!nliCk-=lT!%xF]6`DM"><field name="TEXT">Σύνολο στοιχείων πίνακα</field></shadow></value></block></value><next><block type="variables_set" id="lrGgU^Z-~2TF,6P]ou3n"><field name="VAR" id="Mu`el/F}wJb~:-Kk0t62" variabletype="">A</field><value name="VALUE"><block type="lists_create_with" id="xQ=`fz+rPP^^$#R35aG2"><mutation items="0"></mutation></block></value><next><block type="controls_for" id="A3+NozU5zzjq,to+cRZS"><field name="VAR" id="1gl2iW[A[c:88A3b5ES6" variabletype="">i</field><value name="FROM"><shadow type="math_number" id="$D|X+1l6mo((c$XtP;SP"><field name="NUM">1</field></shadow></value><value name="TO"><shadow type="math_number" id="+cTv}x/},5z{7R!HYP5I"><field name="NUM">10</field></shadow><block type="variables_get" id="!|@A`NZwxglV9a0sHVY!"><field name="VAR" id="Z#/AWt1:c`zJl[5{(3,G" variabletype="">N</field></block></value><value name="BY"><shadow type="math_number" id="DA]^~A7!mjwe{_)M$o$Y"><field name="NUM">1</field></shadow></value><statement name="DO"><block type="lists_setIndex" id="#e|~I*OO(#zm7UrY`-?I"><mutation at="true"></mutation><field name="MODE">SET</field><field name="WHERE">FROM_START</field><value name="LIST"><block type="variables_get" id="=s26*faewMTuH]iAO/.E"><field name="VAR" id="Mu`el/F}wJb~:-Kk0t62" variabletype="">A</field></block></value><value name="AT"><block type="variables_get" id="#F;hEI85,ynx:R/SJY_c"><field name="VAR" id="1gl2iW[A[c:88A3b5ES6" variabletype="">i</field></block></value><value name="TO"><block type="math_random_int" id="G41TF*$rs.MUnIW,3J6|"><value name="FROM"><shadow type="math_number" id="|d=91Kxqc?ld5_(Pp,h."><field name="NUM">1</field></shadow></value><value name="TO"><shadow type="math_number" id="L*)vsAYQ(2*?w0cpP;;f"><field name="NUM">100</field></shadow></value></block></value></block></statement><next><block type="text_print" id="kTJW^rlNBiOd_F*E4I`k"><value name="TEXT"><shadow type="text" id="Q$ascZRS#@8*qI50qv$|"><field name="TEXT">Στοιχεία πίνακα Α πριν την ταξινόμηση</field></shadow></value><next><block type="text_print" id="kD5snJzrpWTkl1Mi.%$L"><value name="TEXT"><shadow type="text" id="s.eYmj;_k0YP^jb^8@Mg"><field name="TEXT">abc</field></shadow><block type="text_join" id="u|Qk[fCo~AeH$:}D{M!t"><mutation items="2"></mutation><value name="ADD0"><block type="text" id="^Xib5XI-$(9_u#c|RilW"><field name="TEXT">Α = </field></block></value><value name="ADD1"><block type="variables_get" id="D2;@D+1WC!gk04{_8k|0"><field name="VAR" id="Mu`el/F}wJb~:-Kk0t62" variabletype="">A</field></block></value></block></value><next><block type="controls_for" id="yN;m%qtVFQDX-Q-dT4]0"><field name="VAR" id="1gl2iW[A[c:88A3b5ES6" variabletype="">i</field><value name="FROM"><shadow type="math_number" id="Cwx};hO46qjz!{}(kBY."><field name="NUM">2</field></shadow></value><value name="TO"><shadow type="math_number" id="ff2l2QsEuP_5visqg27B"><field name="NUM">10</field></shadow><block type="variables_get" id="wCumh;U,Gwk3I9%L$fX4"><field name="VAR" id="Z#/AWt1:c`zJl[5{(3,G" variabletype="">N</field></block></value><value name="BY"><shadow type="math_number" id="X9gK2?g+21(pumEJ/wOh"><field name="NUM">1</field></shadow></value><statement name="DO"><block type="controls_for" id="q*T!1pUGx}EYR9xE)0-$"><field name="VAR" id="1Mn,V*BV[87lM@9b#ea^" variabletype="">j</field><value name="FROM"><shadow type="math_number" id="!B)GG8}-|^7NuwJU2,ko"><field name="NUM">0</field></shadow><block type="variables_get" id="UGDaTqk~q|,[7eO!|H$k"><field name="VAR" id="Z#/AWt1:c`zJl[5{(3,G" variabletype="">N</field></block></value><value name="TO"><shadow type="math_number" id="mpUaiE5[Szd|Jv*_nDTs"><field name="NUM">10</field></shadow><block type="variables_get" id="(n~kWzh$]-atWRkXJLjB"><field name="VAR" id="1gl2iW[A[c:88A3b5ES6" variabletype="">i</field></block></value><value name="BY"><shadow type="math_number" id="jz#Y0CT^]1kjVI0K;S=2"><field name="NUM">-1</field></shadow></value><statement name="DO"><block type="controls_if" id="WsQgTwZ?#$)6q5ZZcfoC"><value name="IF0"><block type="logic_compare" id="AC4C/_(z!O/oO|6o,t%b"><field name="OP">LT</field><value name="A"><block type="lists_getIndex" id="P{Rwr5#{bR[dVmUjL~`4"><mutation statement="false" at="true"></mutation><field name="MODE">GET</field><field name="WHERE">FROM_START</field><value name="VALUE"><block type="variables_get" id="EJIYhLO_p#v4TXTu1Lg}"><field name="VAR" id="Mu`el/F}wJb~:-Kk0t62" variabletype="">A</field></block></value><value name="AT"><block type="variables_get" id="NHb+?Z}2fv,u|-]j%9oY"><field name="VAR" id="1Mn,V*BV[87lM@9b#ea^" variabletype="">j</field></block></value></block></value><value name="B"><block type="lists_getIndex" id="|EDd},gE11t{--AK}u|="><mutation statement="false" at="true"></mutation><field name="MODE">GET</field><field name="WHERE">FROM_START</field><value name="VALUE"><block type="variables_get" id="2RbCQ#a%to=.bp9fii_1"><field name="VAR" id="Mu`el/F}wJb~:-Kk0t62" variabletype="">A</field></block></value><value name="AT"><block type="math_arithmetic" id="}8WH!jKBGvX%+Y,,L|U;"><field name="OP">MINUS</field><value name="A"><shadow type="math_number" id="`4V7i=Q/nbo}^IAISM4o"><field name="NUM">1</field></shadow><block type="variables_get" id="?8~,]=;W*oX){hYdYI}x"><field name="VAR" id="1Mn,V*BV[87lM@9b#ea^" variabletype="">j</field></block></value><value name="B"><shadow type="math_number" id="wdI2@kM+Q`Q2Oz{1i,N9"><field name="NUM">1</field></shadow></value></block></value></block></value></block></value><statement name="DO0"><block type="variables_set" id="236n;lx[lz43z}iqa1q)"><field name="VAR" id="~JGwVE_?FUuT?6W8@og+" variabletype="">Temp</field><value name="VALUE"><block type="lists_getIndex" id="J$Xm3EdQKgvZi7=P~Ux2"><mutation statement="false" at="true"></mutation><field name="MODE">GET</field><field name="WHERE">FROM_START</field><value name="VALUE"><block type="variables_get" id="-Pk#FD[1U}v4x?nSF;r9"><field name="VAR" id="Mu`el/F}wJb~:-Kk0t62" variabletype="">A</field></block></value><value name="AT"><block type="variables_get" id="fncXJl[25;1Dz$KGRVCq"><field name="VAR" id="1Mn,V*BV[87lM@9b#ea^" variabletype="">j</field></block></value></block></value><next><block type="lists_setIndex" id="iaVYl2As^F^O%^bn]:(7"><mutation at="true"></mutation><field name="MODE">SET</field><field name="WHERE">FROM_START</field><value name="LIST"><block type="variables_get" id="WEFXeZs}0C#}k:lgV0k9"><field name="VAR" id="Mu`el/F}wJb~:-Kk0t62" variabletype="">A</field></block></value><value name="AT"><block type="variables_get" id=":nst9^j@qtDO?|0@LTW1"><field name="VAR" id="1Mn,V*BV[87lM@9b#ea^" variabletype="">j</field></block></value><value name="TO"><block type="lists_getIndex" id="40+iQ5-_N$mxeVAqGjl%"><mutation statement="false" at="true"></mutation><field name="MODE">GET</field><field name="WHERE">FROM_START</field><value name="VALUE"><block type="variables_get" id="/HO/Rv8$#NHsm9BeOhwN"><field name="VAR" id="Mu`el/F}wJb~:-Kk0t62" variabletype="">A</field></block></value><value name="AT"><block type="math_arithmetic" id="w@Q1(Vz!{tTSDMvU0IHO"><field name="OP">MINUS</field><value name="A"><shadow type="math_number" id="`4V7i=Q/nbo}^IAISM4o"><field name="NUM">1</field></shadow><block type="variables_get" id="G(#?K44iKO6Vrntl3K?`"><field name="VAR" id="1Mn,V*BV[87lM@9b#ea^" variabletype="">j</field></block></value><value name="B"><shadow type="math_number" id="bL~WhAG))iJG|=9dj6kk"><field name="NUM">1</field></shadow></value></block></value></block></value><next><block type="lists_setIndex" id="7Dh9_ZPQLqgldtFcZ0+u"><mutation at="true"></mutation><field name="MODE">SET</field><field name="WHERE">FROM_START</field><value name="LIST"><block type="variables_get" id="RPgXlF|,@S*pq@$jpqCy"><field name="VAR" id="Mu`el/F}wJb~:-Kk0t62" variabletype="">A</field></block></value><value name="AT"><block type="math_arithmetic" id="atC-EV%[QJcSZF?|x}GC"><field name="OP">MINUS</field><value name="A"><shadow type="math_number" id="`4V7i=Q/nbo}^IAISM4o"><field name="NUM">1</field></shadow><block type="variables_get" id="c$C[Iv57K/$w,%[4Nb_Q"><field name="VAR" id="1Mn,V*BV[87lM@9b#ea^" variabletype="">j</field></block></value><value name="B"><shadow type="math_number" id="0.*yowM8kzS$=Psm5wxg"><field name="NUM">1</field></shadow></value></block></value><value name="TO"><block type="variables_get" id="8CZ$M|zj^!OLQn4+LUWc"><field name="VAR" id="~JGwVE_?FUuT?6W8@og+" variabletype="">Temp</field></block></value></block></next></block></next></block></statement></block></statement></block></statement><next><block type="text_print" id="~zaW[u)RK0Q}ejm;bDBL"><value name="TEXT"><shadow type="text" id="zZ1Th!n[,O7wVr86HN-h"><field name="TEXT">Στοιχεία πίνακα Α μετά την ταξινόμηση</field></shadow></value><next><block type="text_print" id="+~X.m#YF=NVe9nN9hI,w"><value name="TEXT"><shadow type="text" id="s.eYmj;_k0YP^jb^8@Mg"><field name="TEXT">abc</field></shadow><block type="text_join" id="!OvmWbnFfP+5{7f^doMh"><mutation items="2"></mutation><value name="ADD0"><block type="text" id="+M,w6}c)Mtl8LfmRo!5H"><field name="TEXT">Α = </field></block></value><value name="ADD1"><block type="variables_get" id="AqVon8EKoE#jN6?ef{2F"><field name="VAR" id="Mu`el/F}wJb~:-Kk0t62" variabletype="">A</field></block></value></block></value><next><block type="algorithm_end" id="`]mbnN-lD.F|6_KD-(*k"><field name="algorithm_name">Bubble sort</field></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></next></block></xml>');
                break;
            }
        }

    });


/*
    $("#btnSave").click(function() {
        let xml = Blockly.Xml.workspaceToDom(Workspace);
        let xmlText  = Blockly.Xml.domToText(xml); 
        //alert(xmlText);
        document.getElementById('saveArea').value = xmlText;
    });
*/

    function myUpdateFunction(event) {
        let codeJ = Blockly.JavaScript.workspaceToCode(Workspace);
        let res = codeJ.split(";");        
        for(var ik = 0; ik < res.length; ik++) {
            if(res[ik].includes("highlightBlock")) {                
                res.splice(ik,1);
                ik--;
            }            
        }                
        document.getElementById('javascriptArea').value = res.join(";");
                
        let codeP = Blockly.Python.workspaceToCode(Workspace);
        document.getElementById('pythonArea').value = codeP;               
    }
    Workspace.addChangeListener(myUpdateFunction);


    $("#btnPlay").click(function() {
        window.LoopTrap = 1000;
        var code = Blockly.JavaScript.workspaceToCode(Workspace);      
        
        Blockly.JavaScript.INFINITE_LOOP_TRAP = null;
        var myInterpreter = new Interpreter(code, initApi);
        try {
            myInterpreter.run();            
        } catch (e) {
            alert(e);
        }
    }); 


    $("#btnStep").click(function() {
        stepCode();      
    });

    $("#btnStop").click(function() {          
        window.clearTimeout(pid);     
    });

    $("#btnClear").click(function() {          
        outputArea.innerHTML = "";
    });

    $("#btnVar").click(function() {

        var defvars = [];
        var variables = Blockly.Variables.allUsedVarModels(Workspace);
        for (var i = 0; i < variables.length; i++) {
            defvars.push(Blockly.JavaScript.variableDB_.getName(variables[i].getId(),
            Blockly.Variables.NAME_TYPE));
        } 
        alert(defvars.length);
        //alert(myInterpreter.getValueFromScope(defvars[0].name));
        
    });




    


